Dispenser

Struct Dispenser 

pub struct Dispenser { /* private fields */ }
A struct that holds a hidden variable, dispenses Hands with a lock on a state, and shuffles afterward.

Implementations

Source

impl Dispenser

pub fn new(len: usize) -> Self

Creates a new Dispenser, initializing it with choices for a slice of a given len.

pub fn len(&self) -> usize

Returns the effective len argument given to new for this object.

pub fn make_hand<'h, T>(&mut self, deck: &'h [T]) -> Option<Hand<'h, T>>

Creates a Hand from deck and an internal variable, this shuffles the variable afterwards.

This makes first sure that all possible choices are possible for deck, it does this by checking the length of deck, and effectively comparing it to the len given when the Dispenser was created.

This function returns None when it’s possible that elements in deck cannot be chosen, or there are more possible choices than that deck has. (deck.len() != len)

This function returns Some when checks pass, and all choices has a corresponding element in deck.

pub fn make_hand_unchecked<'h, T>(&mut self, deck: &'h [T]) -> Hand<'h, T>

Creates a Hand, similar to make_hand, but without the check to see if all choices can land, and all elements are choosable.