pub struct Dispenser { /* private fields */ }Expand description
A struct that holds a hidden variable, dispenses Hands with a lock on a
state, and shuffles afterward.
Implementations
Sourceimpl Dispenser
impl Dispenser
Sourcepub fn new(len: usize) -> Self
pub fn new(len: usize) -> Self
Creates a new Dispenser, initializing it with choices for a slice of a given
len.
Sourcepub fn make_hand<'h, T>(&mut self, deck: &'h [T]) -> Option<Hand<'h, T>>
pub fn make_hand<'h, T>(&mut self, deck: &'h [T]) -> Option<Hand<'h, T>>
Creates a Hand from deck and an internal variable, this shuffles the variable afterwards.
This makes first sure that all possible choices are possible for deck, it does this by
checking the length of deck, and effectively comparing it to the len given when the
Dispenser was created.
This function returns None when it’s possible that elements in deck cannot be chosen, or
there are more possible choices than that deck has. (deck.len() != len)
This function returns Some when checks pass, and all choices has a corresponding element
in deck.